# -*- coding: utf-8 -*-

from openaccess_epub.ops.opsmeta import OPSMeta
from openaccess_epub.ops.opsplos import OPSPLoS
from openaccess_epub.ops.opsfrontiers import OPSFrontiers

import logging

log = logging.getLogger('openaccess_epub.ops')
